<?php


require_once("pbx.base.php");

class PbxSoapClient extends SoapClient {
    var $user;
    var $password;
    var $multi = null;
    var $ch = null;
    
    public function __construct($wsdl, $options, $user, $password) {
        $this->user = $user;
        $this->password = $password;
        parent::__construct($wsdl, $options);
    }
    
    public function __destruct() {
        $this->closeSocket();
    }
    
    private function closeSocket() {
        if($this->ch) {
            curl_close($this->ch);
            $this->ch = null;
        }
    }
    
    /**
    * Performs a SOAP request
    	 * 
    * @link http://php.net/manual/en/function.soap-soapclient-dorequest.php
    	 * 
    * @param string $request the xml soap request
    * @param string $location the url to request
    * @param string $action the soap action.
    * @param integer $version the soap version
    * @param integer $one_way
    * @return string the xml soap response.
    	 */
    public function __doRequest($request, $location, $action, $version, $one_way = 0) {
        $headers = array(
            'Method: POST',
            'Connection: Keep-Alive',
            'User-Agent: PHP-SOAP-CURL',
            'Content-Type: text/xml; charset=utf-8',
            'SOAPAction: "'.$action.'"',
            ); // end $headers
        if(!$this->ch) {
            $this->ch = curl_init($location);
        }
        
        curl_setopt($this->ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($this->ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($this->ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($this->ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($this->ch, CURLOPT_POST, true );
        curl_setopt($this->ch, CURLOPT_POSTFIELDS, $request);
        curl_setopt($this->ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($this->ch, CURLOPT_USERPWD, $this->user.':'.$this->password);
        curl_setopt($this->ch, CURLOPT_CONNECTTIMEOUT, 10);
        curl_setopt($this->ch, CURLOPT_TIMEOUT, 65);
        
        $response = curl_exec($this->ch);
        if($response === false) {
            $error = curl_error($this->ch)." (".curl_errno($this->ch).")";
            $this->closeSocket();
            throw new Exception($error);
        }
        elseif(($httpStatus = curl_getinfo($this->ch, CURLINFO_HTTP_CODE)) !== 200) {
            $this->closeSocket();
            throw new Exception("Curl HTTP Status $httpStatus");
        }
        return $response;
    } // end function __doRequest()
}

/**
 * Implementation class of pbx.
 *
 * You may modify this class for custom logic additions/methode overrides.
 * If you do so, don't forget to call the overriden super-class method!
 *
 * This stub was generated using WSDLInterpreter on Mon, 20 Feb 2012 11:10:42 +0100
 *
 * @see pbxBase
 */

class pbx extends pbxBase
{
    var $ipAddr;
    var $dynPbxIp;
    var $https;
    
    public function __construct($ipAddr, $user, $password, $https = false, $dynPbxIp = "", $port = "") {
        $this->ipAddr = $ipAddr;
        $this->dynPbxIp = $dynPbxIp;
        $this->https = $https;
        $wsdl = dirname(__FILE__).'/wsdl/pbx10_00.wsdl';
        $options = array();
        $options["password"] = $password;
        $options["login"] = $user;
        $id = "PBX0";
        if($dynPbxIp != "") {
            $id .= "-$dynPbxIp";
        }
        $proto = "http";
        if($https) {
            $proto .= "s";
        }
        $portStr = "";
        $port = intval($port);
        if($port > 0) {
            $portStr = ":$port";
        }
        $options["location"] = "$proto://{$ipAddr}{$portStr}/$id/user.soap";
        $options["authentication"] = SOAP_AUTHENTICATION_DIGEST;
        $options = pbxBase::getClassMapOptions($options);
        $soapClient = new PbxSoapClient($wsdl, $options, $user, $password);
        parent::__construct($wsdl, $soapClient, $options);
    }
}